pub struct MlmeGetApfPacketFilterEnabledResponse {
pub enabled: bool,
}Fields
enabled: boolTrait Implementations
Sourceimpl Clone for MlmeGetApfPacketFilterEnabledResponse
impl Clone for MlmeGetApfPacketFilterEnabledResponse
Sourcefn clone(&self) -> MlmeGetApfPacketFilterEnabledResponse
fn clone(&self) -> MlmeGetApfPacketFilterEnabledResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<D> Decode<MlmeGetApfPacketFilterEnabledResponse, D> for MlmeGetApfPacketFilterEnabledResponsewhere
D: ResourceDialect,
impl<D> Decode<MlmeGetApfPacketFilterEnabledResponse, D> for MlmeGetApfPacketFilterEnabledResponsewhere
D: ResourceDialect,
Sourcefn new_empty() -> MlmeGetApfPacketFilterEnabledResponse
fn new_empty() -> MlmeGetApfPacketFilterEnabledResponse
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl<D> Encode<MlmeGetApfPacketFilterEnabledResponse, D> for &MlmeGetApfPacketFilterEnabledResponsewhere
D: ResourceDialect,
impl<D> Encode<MlmeGetApfPacketFilterEnabledResponse, D> for &MlmeGetApfPacketFilterEnabledResponsewhere
D: ResourceDialect,
Sourceimpl Ord for MlmeGetApfPacketFilterEnabledResponse
impl Ord for MlmeGetApfPacketFilterEnabledResponse
Sourcefn cmp(&self, other: &MlmeGetApfPacketFilterEnabledResponse) -> Ordering
fn cmp(&self, other: &MlmeGetApfPacketFilterEnabledResponse) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for MlmeGetApfPacketFilterEnabledResponse
impl PartialEq for MlmeGetApfPacketFilterEnabledResponse
Sourcefn eq(&self, other: &MlmeGetApfPacketFilterEnabledResponse) -> bool
fn eq(&self, other: &MlmeGetApfPacketFilterEnabledResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for MlmeGetApfPacketFilterEnabledResponse
impl PartialOrd for MlmeGetApfPacketFilterEnabledResponse
Sourceimpl TypeMarker for MlmeGetApfPacketFilterEnabledResponse
impl TypeMarker for MlmeGetApfPacketFilterEnabledResponse
Sourcetype Owned = MlmeGetApfPacketFilterEnabledResponse
type Owned = MlmeGetApfPacketFilterEnabledResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for MlmeGetApfPacketFilterEnabledResponse
impl ValueTypeMarker for MlmeGetApfPacketFilterEnabledResponse
Sourcetype Borrowed<'a> = &'a MlmeGetApfPacketFilterEnabledResponse
type Borrowed<'a> = &'a MlmeGetApfPacketFilterEnabledResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<MlmeGetApfPacketFilterEnabledResponse as TypeMarker>::Owned,
) -> <MlmeGetApfPacketFilterEnabledResponse as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<MlmeGetApfPacketFilterEnabledResponse as TypeMarker>::Owned, ) -> <MlmeGetApfPacketFilterEnabledResponse as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.impl Copy for MlmeGetApfPacketFilterEnabledResponse
impl Eq for MlmeGetApfPacketFilterEnabledResponse
impl Persistable for MlmeGetApfPacketFilterEnabledResponse
impl StructuralPartialEq for MlmeGetApfPacketFilterEnabledResponse