pub struct MlmeInstallApfPacketFilterRequest {
pub program: Vec<u8>,
}Fields
program: Vec<u8>Trait Implementations
Sourceimpl Clone for MlmeInstallApfPacketFilterRequest
impl Clone for MlmeInstallApfPacketFilterRequest
Sourcefn clone(&self) -> MlmeInstallApfPacketFilterRequest
fn clone(&self) -> MlmeInstallApfPacketFilterRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<D> Decode<MlmeInstallApfPacketFilterRequest, D> for MlmeInstallApfPacketFilterRequestwhere
D: ResourceDialect,
impl<D> Decode<MlmeInstallApfPacketFilterRequest, D> for MlmeInstallApfPacketFilterRequestwhere
D: ResourceDialect,
Sourcefn new_empty() -> MlmeInstallApfPacketFilterRequest
fn new_empty() -> MlmeInstallApfPacketFilterRequest
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl<D> Encode<MlmeInstallApfPacketFilterRequest, D> for &MlmeInstallApfPacketFilterRequestwhere
D: ResourceDialect,
impl<D> Encode<MlmeInstallApfPacketFilterRequest, D> for &MlmeInstallApfPacketFilterRequestwhere
D: ResourceDialect,
Sourceimpl Ord for MlmeInstallApfPacketFilterRequest
impl Ord for MlmeInstallApfPacketFilterRequest
Sourcefn cmp(&self, other: &MlmeInstallApfPacketFilterRequest) -> Ordering
fn cmp(&self, other: &MlmeInstallApfPacketFilterRequest) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for MlmeInstallApfPacketFilterRequest
impl PartialEq for MlmeInstallApfPacketFilterRequest
Sourcefn eq(&self, other: &MlmeInstallApfPacketFilterRequest) -> bool
fn eq(&self, other: &MlmeInstallApfPacketFilterRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for MlmeInstallApfPacketFilterRequest
impl PartialOrd for MlmeInstallApfPacketFilterRequest
Sourceimpl TypeMarker for MlmeInstallApfPacketFilterRequest
impl TypeMarker for MlmeInstallApfPacketFilterRequest
Sourcetype Owned = MlmeInstallApfPacketFilterRequest
type Owned = MlmeInstallApfPacketFilterRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for MlmeInstallApfPacketFilterRequest
impl ValueTypeMarker for MlmeInstallApfPacketFilterRequest
Sourcetype Borrowed<'a> = &'a MlmeInstallApfPacketFilterRequest
type Borrowed<'a> = &'a MlmeInstallApfPacketFilterRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<MlmeInstallApfPacketFilterRequest as TypeMarker>::Owned,
) -> <MlmeInstallApfPacketFilterRequest as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<MlmeInstallApfPacketFilterRequest as TypeMarker>::Owned, ) -> <MlmeInstallApfPacketFilterRequest as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.impl Eq for MlmeInstallApfPacketFilterRequest
impl Persistable for MlmeInstallApfPacketFilterRequest
impl StructuralPartialEq for MlmeInstallApfPacketFilterRequest