ScanRequest

Struct ScanRequest 

pub struct ScanRequest {
    pub txn_id: u64,
    pub scan_type: ScanTypes,
    pub channel_list: Vec<ChannelNumber>,
    pub ssid_list: Vec<Vec<u8>>,
    pub probe_delay: u32,
    pub min_channel_time: u32,
    pub max_channel_time: u32,
}

Fields

txn_id: u64scan_type: ScanTypeschannel_list: Vec<ChannelNumber>

List of channels to scan on. An empty list of channels will cause a scan request to immediately return a ScanEnd with code INVALID_ARGS.

Invalid channel numbers will be silently ignored. The validity of a channel number depends on the current regulatory region, and MLME does not control or know this setting.

ssid_list: Vec<Vec<u8>>

List of SSIDs to scan for. An empty list of ssids is the same as specifying a list containing only the wildcard SSID.

There is no limit on the number of SSIDs specified. A large number of SSIDs may result in extended scan times because of hardware limitations on the number of SSIDs permitted per scan request and the technical limitation in IEEE 802.11-2016 that limits the number of SSIDs in a single Probe Request frame to ieee80211.SSID_LIST_MAX SSIDs.

probe_delay: u32min_channel_time: u32max_channel_time: u32